@@ -9,11 +9,10 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkMacMenus.c,v 1.8 2002/01/27 11:11:02 das Exp $
+ * SCCS: @(#) tkMacMenus.c 1.24 96/08/01 20:59:12
  */
 
 #include "tcl.h"
-#include "tclMacInt.h" /* Needed for FSpLocationFromPath */
 #include "tk.h"
 #include "tkInt.h"
 #include "tkMacInt.h"
@@ -29,7 +28,8 @@
 #include <SegLoad.h>
 #include <StandardFile.h>
 #include <ToolUtils.h>
-#include <Balloons.h>
+
+#include <FullPath.h>
 
 #define kAppleMenu		256
 #define kAppleAboutItem		1
@@ -45,13 +45,14 @@
 #define EDIT_PASTE		3
 #define EDIT_CLEAR		4
 
-MenuHandle tkAppleMenu;
-MenuHandle tkFileMenu;
-MenuHandle tkEditMenu;
-
 static Tcl_Interp *	gInterp;	/* Interpreter for this application. */
+static MenuHandle	gAppleM;	/* Handles to menus */
+static MenuHandle	gFileM;		/* Handles to menus */
+static MenuHandle	gEditM;		/* Handles to menus */
 
-static void GenerateEditEvent _ANSI_ARGS_((int flag));
+Tk_Window Tk_TopCoordsToWindow _ANSI_ARGS_((Tk_Window tkwin, int rootX,
+			int rootY, int *newX, int *newY));
+static void FakeEditEvent _ANSI_ARGS_((int flag));
 static void SourceDialog _ANSI_ARGS_((void));
 
 /*
@@ -71,20 +72,17 @@ static void SourceDialog _ANSI_ARGS_((void));
  */
 
 void 
-TkMacHandleMenuSelect(
-    long mResult,
-    int optionKeyPressed)
+TkMacHandleMenuSelect(mResult, optionKeyPressed)
+    long mResult;
+    int optionKeyPressed;
 {
     short theItem = LoWord(mResult);
     short theMenu = HiWord(mResult);
     Str255 name;
     Tk_Window tkwin;
     Window window;
-    TkDisplay *dispPtr;
 
     if (mResult == 0) {
-    	TkMacHandleTearoffMenu();
-	TkMacClearMenubarActive();
 	return;
     }
 
@@ -106,7 +104,7 @@ TkMacHandleMenuSelect(
 			break;
 		    }
 		default:
-		    GetMenuItemText(tkAppleMenu, theItem, name);
+		    GetItem(gAppleM, theItem, name);
 		    HiliteMenu(0);
 		    OpenDeskAcc(name);
 		    return;
@@ -120,13 +118,8 @@ TkMacHandleMenuSelect(
 		    break;
 		case kCloseItem:
 		    /* Send close event */
-		    if (TkMacHaveAppearance() >= 0x110) {
-		        window = TkMacGetXWindow(FrontNonFloatingWindow());
-		    } else {
-		        window = TkMacGetXWindow(FrontWindow());
-		    }
-		    dispPtr = TkGetDisplayList();
-		    tkwin = Tk_IdToWindow(dispPtr->display, window);
+		    window = TkMacGetXWindow(FrontWindow());
+		    tkwin = Tk_IdToWindow(tkDisplayList->display, window);
 		    TkGenWMDestroyEvent(tkwin);
 		    break;
 		case kQuitItem:
@@ -145,11 +138,13 @@ TkMacHandleMenuSelect(
 	     * the Tk thinks are associated with function keys that
 	     * do Cut, Copy & Paste on a Sun keyboard.
 	     */
-	    GenerateEditEvent(theItem);
+	    FakeEditEvent(theItem);
 	    break;
 	default:
-	    TkMacDispatchMenuEvent(theMenu, theItem);
-	    TkMacClearMenubarActive();
+	    /*
+	     * This will eventually evoke Tcl scripts
+	     * TODO: come up with frame work for this...
+	     */
 	    break;
     }
 
@@ -176,69 +171,65 @@ TkMacHandleMenuSelect(
  */
 
 void 
-TkMacInitMenus(
-    Tcl_Interp 	*interp)
+TkMacInitMenus(interp)
+    Tcl_Interp 	*interp;
 {
+    Handle mbarH;
+
     gInterp = interp;
 
     /* 
      * At this point, InitMenus() should have already been called. 
      */
 
-    if (TkMacUseMenuID(256) != TCL_OK) {
-    	panic("Menu ID 256 is already in use!");
+    mbarH = (Handle) GetMenuBar();
+    if (mbarH == NULL) {
+	panic("memory - menu bar");
     }
-    tkAppleMenu = NewMenu(256, "\p\024");
-    if (tkAppleMenu == NULL) {
-	panic("memory - menus");
-    }
-    InsertMenu(tkAppleMenu, 0);
-    AppendMenu(tkAppleMenu, "\pAbout Tcl & Tk");
-    AppendMenu(tkAppleMenu, "\p(-");
-    AppendResMenu(tkAppleMenu, 'DRVR');
 
-    if (TkMacUseMenuID(kFileMenu) != TCL_OK) {
-    	panic("Menu ID %d is already in use!", kFileMenu);
-    }
-    tkFileMenu = NewMenu(kFileMenu, "\pFile");
-    if (tkFileMenu == NULL) {
+    gAppleM = NewMenu(256, "\p\024");
+    if (gAppleM == NULL) {
 	panic("memory - menus");
     }
-    InsertMenu(tkFileMenu, 0);
-    AppendMenu(tkFileMenu, "\pSource");
-    AppendMenu(tkFileMenu, "\pClose/W");
-    AppendMenu(tkFileMenu, "\p(-");
-    AppendMenu(tkFileMenu, "\pQuit/Q");
+    InsertMenu(gAppleM, 0);
+    AppendMenu(gAppleM, "\pAbout Tcl & Tk");
+    AppendMenu(gAppleM, "\p(-");
+    AddResMenu(gAppleM, 'DRVR');
 
-    if (TkMacUseMenuID(kEditMenu) != TCL_OK) {
-    	panic("Menu ID %d is already in use!", kEditMenu);
-    }
-    tkEditMenu = NewMenu(kEditMenu, "\pEdit");
-    if (tkEditMenu == NULL) {
+    gFileM = NewMenu(kFileMenu, "\pFile");
+    if (gFileM == NULL) {
 	panic("memory - menus");
     }
-    InsertMenu(tkEditMenu, 0);
-    AppendMenu(tkEditMenu, "\pCut/X");
-    AppendMenu(tkEditMenu, "\pCopy/C");
-    AppendMenu(tkEditMenu, "\pPaste/V");
-    AppendMenu(tkEditMenu, "\pClear");
-    if (TkMacUseMenuID(kHMHelpMenuID) != TCL_OK) {
-    	panic("Help menu ID %s is already in use!", kHMHelpMenuID);
+    InsertMenu(gFileM, 0);
+    AppendMenu(gFileM, "\pSource");
+    AppendMenu(gFileM, "\pClose/W");
+    AppendMenu(gFileM, "\p(-");
+    AppendMenu(gFileM, "\pQuit/Q");
+
+    gEditM = NewMenu(kEditMenu, "\pEdit");
+    if (gEditM == NULL) {
+	panic("memory - menus");
     }
-    
+    InsertMenu(gEditM, 0);
+    AppendMenu(gEditM, "\pCut/X");
+    AppendMenu(gEditM, "\pCopy/C");
+    AppendMenu(gEditM, "\pPaste/V");
+
     DrawMenuBar();
-    TkMacSetHelpMenuItemCount();
-    
+
+    DisposeHandle(mbarH);
+
     return;
 }
 
 /*
  *----------------------------------------------------------------------
  *
- * GenerateEditEvent --
+ * FakeEditEvent --
  *
- *	Takes an edit menu item and posts the corasponding a virtual 
- *	event to Tk's event queue.
+ *	Takes an edit menu item and simulates thier actions by sending
+ *	fake keyboard events to Tk's event queue.  Eventually this
+ *	should be replaced by a better mechanism.
  *
  * Results:
  *	None.
@@ -250,63 +241,76 @@ TkMacInitMenus(
  */
 
 static void 
-GenerateEditEvent(
-    int flag)
+FakeEditEvent(flag)
+    int flag;
 {
-    XVirtualEvent event;
+    XEvent event;
+    WindowRef frontWin;
+    Window window;
     Point where;
     Tk_Window tkwin;
-    Window window;
-    TkDisplay *dispPtr;
 
-    if (TkMacHaveAppearance() >= 0x110) {
-        window = TkMacGetXWindow(FrontNonFloatingWindow());
-    } else {
-        window = TkMacGetXWindow(FrontWindow());
-    }
-    dispPtr = TkGetDisplayList();
-    tkwin = Tk_IdToWindow(dispPtr->display, window);
-    tkwin = (Tk_Window) ((TkWindow *) tkwin)->dispPtr->focusPtr;
+    /* 
+     * Find the window 
+     */
+    frontWin = FrontWindow();
+    window = TkMacGetXWindow(frontWin);
+    tkwin = Tk_IdToWindow(tkDisplayList->display, window);
     if (tkwin == NULL) {
-	return;
+        return;
     }
 
-    event.type = VirtualEvent;
-    event.serial = Tk_Display(tkwin)->request;
-    event.send_event = false;
-    event.display = Tk_Display(tkwin);
-    event.event = Tk_WindowId(tkwin);
-    event.root = XRootWindow(Tk_Display(tkwin), 0);
-    event.subwindow = None;
-    event.time = TkpGetMS();
-    
+    event.xany.send_event = false;
+    event.xkey.same_screen = true;
+    event.xkey.subwindow = None;
+    event.xkey.time = GenerateTime();
+
     GetMouse(&where);
     tkwin = Tk_TopCoordsToWindow(tkwin, where.h, where.v, 
-	    &event.x, &event.y);
+	    &event.xkey.x, &event.xkey.y);
     LocalToGlobal(&where);
-    event.x_root = where.h;
-    event.y_root = where.v;
-    event.state = TkMacButtonKeyState();
-    event.same_screen = true;
+    event.xkey.x_root = where.h;
+    event.xkey.y_root = where.v;
+
+    event.xany.serial = Tk_Display(tkwin)->request;
+    event.xkey.window = Tk_WindowId(tkwin);
+    event.xkey.display = Tk_Display(tkwin);
+    event.xkey.root = XRootWindow(Tk_Display(tkwin), 0);
     
     switch (flag) {
 	case EDIT_CUT:
-	    event.name = Tk_GetUid("Cut");
+	    event.xkey.keycode = 0x00020D17;
+	    event.xkey.state = ControlMask;
+	    event.xany.type = KeyPress;
+	    Tk_QueueWindowEvent(&event, TCL_QUEUE_TAIL);
+	    event.xany.type = KeyRelease;
+	    Tk_QueueWindowEvent(&event, TCL_QUEUE_TAIL);
 	    break;
-	    
 	case EDIT_COPY:
-	    event.name = Tk_GetUid("Copy");
+	    /*
+	     * Meta doesn't work yet - use Control-i as short term hack
+	     */
+	    event.xkey.state = ControlMask;
+	    event.xkey.keycode = 0x00022209;
+	    event.xany.type = KeyPress;
+	    Tk_QueueWindowEvent(&event, TCL_QUEUE_TAIL);
+	    event.xany.type = KeyRelease;
+	    Tk_QueueWindowEvent(&event, TCL_QUEUE_TAIL);
 	    break;
-	    
 	case EDIT_PASTE:
-	    event.name = Tk_GetUid("Paste");
+	    event.xkey.keycode = 0x00021019;
+	    event.xkey.state = ControlMask;
+	    event.xany.type = KeyPress;
+	    Tk_QueueWindowEvent(&event, TCL_QUEUE_TAIL);
+	    event.xany.type = KeyRelease;
+	    Tk_QueueWindowEvent(&event, TCL_QUEUE_TAIL);
 	    break;
-	    
 	case EDIT_CLEAR:
-	    event.name = Tk_GetUid("Clear");
+	    /*
+	     * TODO: figure out a way to do this.
+	     */
 	    break;
     }
-    Tk_QueueWindowEvent((XEvent *) &event, TCL_QUEUE_TAIL);
 }
 
 /*
@@ -329,27 +333,29 @@ GenerateEditEvent(
 static void 
 SourceDialog()
 {
-    int result;
-    CONST char *path;
-    char openCmd[] = "tk_getOpenFile -filetypes {\
-            {{TCL Scripts} {.tcl} TEXT} {{Text Files} {} TEXT}}";
+    StandardFileReply reply;
+    OSType fileTypes[1];
+    OSErr err;
+    short length;
+    Handle path;
     
     if (gInterp == NULL) {
 	return;
     }
     
-    if (Tcl_Eval(gInterp, openCmd) != TCL_OK) {
+    fileTypes[0] = 'TEXT';
+    StandardGetFile(NULL, 1, fileTypes, &reply);
+    if (reply.sfGood == false) {
 	return;
     }
     
-    path = Tcl_GetStringResult(gInterp);
-    
-    if (strlen(path) == 0) {
-        return;
-    }
-    
-    result = Tcl_EvalFile(gInterp, path);
-    if (result == TCL_ERROR) {
-	Tcl_BackgroundError(gInterp);
-    }	   
+    err = FSpGetFullPath(&reply.sfFile, &length, &path);
+    if (err == noErr) {
+	SetHandleSize(path, length + 1);
+	HLock(path);
+	((char *) (*path))[length] = '\0';
+	Tcl_EvalFile(gInterp, *path);
+	HUnlock(path);
+	DisposeHandle(path);
+    }		   
 }
